@@ -1,6 +1,5 @@
 import ast
 import json
-import requests
 import logging
 from uuid import UUID
 from typing import Tuple, List, Optional, Any, Callable, Dict
@@ -24,7 +23,7 @@ class RKAdmin(RKClient):
         :return: first element: error message
                  second element: True for success, False for error
         """
-        resp = requests.post(url=self.receiver_url + "/clean", timeout=self.timeout_sec)
+        resp = self.session.post(url=self.receiver_url + "/clean", timeout=self.timeout_sec)
         if resp.status_code != 200:
             return f"Error occurred: {resp.status_code}, {resp.text}", False
         return '', True
@@ -44,7 +43,7 @@ class RKAdmin(RKClient):
         query_params: Dict[str, Any] = _parse_params(page_index, page_size, sort_field, sort_order, filters)
 
         def _get_pems() -> Tuple[List[Any], str, bool]:
-            resp = requests.get(url=self.receiver_url + "/pems", timeout=self.timeout_sec, params=query_params)
+            resp = self.session.get(url=self.receiver_url + "/pems", timeout=self.timeout_sec, params=query_params)
             if resp.status_code != 200:
                 return [], f"Error occurred: {resp.status_code}", False
             pems = []
@@ -65,7 +64,7 @@ class RKAdmin(RKClient):
         query_params: Dict[str, Any] = _parse_params(page_index, page_size, sort_field, sort_order, filters)
 
         def _get_pems() -> Tuple[int, str, bool]:
-            resp = requests.get(url=self.receiver_url + "/pems_count", timeout=self.timeout_sec, params=query_params)
+            resp = self.session.get(url=self.receiver_url + "/pems_count", timeout=self.timeout_sec, params=query_params)
             if resp.status_code != 200:
                 return -1, f"Error occurred: {resp.status_code}", False
             obj = json.loads(resp.text)
@@ -88,7 +87,7 @@ class RKAdmin(RKClient):
         return None, False
 
     def get_taxonomy_file(self, taxonomy_id: UUID) -> Tuple[str, bool]:
-        resp = requests.get(url=self.receiver_url + f"/taxonomy/{taxonomy_id.hex}", timeout=self.timeout_sec)
+        resp = self.session.get(url=self.receiver_url + f"/taxonomy/{taxonomy_id.hex}", timeout=self.timeout_sec)
         if resp.status_code != 200:
             return f"Error occurred: {resp.status_code}, {resp.text}", False
         return _decode_from_base64(resp.text), True
@@ -127,7 +126,7 @@ class RKAdmin(RKClient):
         query_params: Dict[str, Any] = _parse_params(page_index, page_size, sort_field, sort_order, filters)
 
         def _get_artifacts_count_from_sql() -> Tuple[int, str, bool]:
-            resp = requests.get(url=self.receiver_url + "/artifacts_count", timeout=self.timeout_sec, params=query_params)
+            resp = self.session.get(url=self.receiver_url + "/artifacts_count", timeout=self.timeout_sec, params=query_params)
             if resp.status_code != 200:
                 return -1, f"Error occurred: {resp.status_code}", False
             objs = json.loads(resp.text)
@@ -144,13 +143,13 @@ class RKAdmin(RKClient):
                  second element: True for success, False for error
         """
         query_fmt = f'"query": "{query}", "type": "{query_type}"'
-        resp = requests.post(url=self.receiver_url + "/query", data='{' + query_fmt + '}', timeout=self.timeout_sec)
+        resp = self.session.post(url=self.receiver_url + "/query", data='{' + query_fmt + '}', timeout=self.timeout_sec)
         if resp.status_code != 200:
             return f"Error occurred: {resp.status_code}", False
         return resp.text, True
 
     def _get_artifacts_from_sql(self, query_params: Dict[str, Any]) -> Tuple[List[Artifact], str, bool]:
-        resp = requests.get(url=self.receiver_url + "/artifacts", timeout=self.timeout_sec, params=query_params)
+        resp = self.session.get(url=self.receiver_url + "/artifacts", timeout=self.timeout_sec, params=query_params)
         if resp.status_code != 200:
             return [], f"Error occurred: {resp.status_code}", False
 
@@ -181,7 +180,7 @@ class RKAdmin(RKClient):
         """
 
         def _get_tags() -> Tuple[List[Any], str, bool]:
-            resp = requests.get(url=self.receiver_url + "/tags", timeout=self.timeout_sec)
+            resp = self.session.get(url=self.receiver_url + "/tags", timeout=self.timeout_sec)
             if resp.status_code != 200:
                 return [], f"Error occurred: {resp.status_code}", False
             tags = json.loads(resp.text)
