@@ -1,10 +1,12 @@
 import time
 import logging
 import datetime
-import requests
 from uuid import UUID, uuid1
 from typing import Dict, Any, Optional, Tuple, Callable
 from importlib.metadata import version
+from urllib3.exceptions import InsecureRequestWarning
+
+import requests
 from requests.exceptions import RequestException
 
 from rkclient.entities import PEM, Artifact
@@ -36,13 +38,18 @@ class RKClient:
 
     """
 
-    def __init__(self, receiver_url: str, emitter_id: Optional[UUID] = None, timeout_sec: int = 5):
-        self.receiver_url = receiver_url
+    def __init__(self, receiver_url: str, emitter_id: Optional[UUID] = None, timeout_sec: int = 5, insecure: bool = True):
+        self.receiver_url = receiver_url.rstrip('/')
         if emitter_id is None:
             emitter_id = uuid1()
         self.emitter_id = emitter_id
         self.timeout_sec = timeout_sec
-        log.info(f"ver {RK_VERSION}, connecting to: {receiver_url}")
+        self.session = requests.Session()
+        log.info(f"ver {RK_VERSION}, connecting to: {self.receiver_url}")
+        if insecure:
+            self.session.verify = False
+            requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
+            log.warning("Disabled SSL certificate check")
 
     def __enter__(self):
         return self
@@ -108,7 +115,7 @@ class RKClient:
         payload: str = PEMSerialization.to_json(pem)
 
         def _send_pem():
-            return requests.post(url=self.receiver_url, data=payload, timeout=self.timeout_sec)
+            return self.session.post(url=self.receiver_url + "/pem", data=payload, timeout=self.timeout_sec)
         log.debug(f"sending PEM: {payload}")
         return _handle_request(_send_pem, "sending PEM")
 
@@ -117,7 +124,7 @@ class RKClient:
         :return: check class description
         """
         def _ping():
-            return requests.get(url=self.receiver_url + "/ping", timeout=self.timeout_sec)
+            return self.session.get(url=self.receiver_url + "/ping", timeout=self.timeout_sec)
         return _handle_request(_ping, "pinging")
 
     def get_info(self) -> Tuple[str, bool]:
@@ -127,7 +134,7 @@ class RKClient:
         TODO: return object instead of str
         """
         def _get_info():
-            return requests.get(url=self.receiver_url + "/info", timeout=self.timeout_sec)
+            return self.session.get(url=self.receiver_url + "/info", timeout=self.timeout_sec)
         return _handle_request(_get_info, "getting info", True)
 
     def get_tag(self, namespace: UUID, tag_name: str) -> Tuple[str, bool]:
@@ -138,7 +145,7 @@ class RKClient:
         tag_base64 = _encode_as_base64(tag_name)
 
         def _get_tag():
-            return requests.get(url=self.receiver_url + f"/tag/{namespace.hex}/{tag_base64}", timeout=self.timeout_sec)
+            return self.session.get(url=self.receiver_url + f"/tag/{namespace.hex}/{tag_base64}", timeout=self.timeout_sec)
         return _handle_request(_get_tag, "getting tag", True)
 
     def set_tag(self, namespace: UUID, tag_name: str, pem: PEM) -> Tuple[str, bool]:
@@ -152,7 +159,7 @@ class RKClient:
         tag_base64 = _encode_as_base64(tag_name)
 
         def _set_tag():
-            return requests.post(url=self.receiver_url + f"/tag/{namespace.hex}/{tag_base64}/{pem.ID.hex}", timeout=self.timeout_sec)
+            return self.session.post(url=self.receiver_url + f"/tag/{namespace.hex}/{tag_base64}/{pem.ID.hex}", timeout=self.timeout_sec)
         return _handle_request(_set_tag, "setting tag")
 
 
